.. currentmodule:: orangewidget.utils.messagewidget

:mod:`orangewidget.utils.messagewidget`
---------------------------------------

.. automodule:: orangewidget.utils.messagewidget

.. autoclass:: MessagesWidget
   :members:
   :member-order: bysource
   :exclude-members: Message, Severity


.. autoclass:: Severity
   :members:


.. autoclass:: Message
   :members:
   :exclude-members: Severity

   .. attribute:: Severity

      Alias for :class:`.Severity`
